@@ -3,4 +3,7 @@ import os
 print("Starting...")
 print("Converting...")
 (stat, output) = subprocess.getstatusoutput("python ExampleScript.py build")
-print("Done...At "+os.getcwd())
+path = os.path.realpath(__file__).split("\\")
+path[len(path)-1] = "build"
+print("Done...At "+ "\\".join(path))
+
